@@ -13,7 +13,7 @@
 #include <dirent.h>
 #include <unistd.h>
 #define direct dirent
-#else
+#elif !defined(_MSC_VER)
 #include <sys/dir.h>
 #endif
 
@@ -21,20 +21,30 @@
 #include <errno.h>
 #include <limits.h>
 
+#ifndef XC_WIN32
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
 #include <X11/Shell.h>
 #include <X11/Xutil.h>
 #include <X11/cursorfont.h>
-
+#endif
 #ifdef TCL_WRAPPER 
 #include <tk.h>
 #else
+#ifndef XC_WIN32
 #include "Xw/Xw.h"
 #include "Xw/WorkSpace.h"
 #include "Xw/TextEdit.h"
 #include "Xw/Toggle.h"
 #endif
+#endif
+
+#if defined(XC_WIN32) && defined(TCL_WRAPPER)
+#include <X11/Xlib.h>
+#include <X11/Xutil.h>
+#include <X11/cursorfont.h>
+#endif
+
 
 /*-------------------------------------------------------------------------*/
 /* Local includes							   */
@@ -79,6 +89,8 @@ GC	 hgc = NULL, sgc = NULL;
 char	 *cwdname = NULL;
 fileliststruct *files;
 
+#if !defined(XC_WIN32) || defined(TCL_WRAPPER)
+
 /*-------------------------------------------------------------------------*/
 /* Compare two filenames (for use by qsort())				   */
 /*-------------------------------------------------------------------------*/
@@ -173,6 +185,8 @@ void endfiletrack(xcWidget w, caddr_t clientdata, XCrossingEvent *event)
    XSetFunction(dpy, areawin->gc, areawin->gctype);
 }
 
+#endif
+
 /*----------------------------------------------------------------------*/
 /* Read a crash file to find the name of the original file.		*/
 /*----------------------------------------------------------------------*/
@@ -232,7 +246,9 @@ void findcrashfiles()
    DIR *cwd;
    struct direct *dp;
    struct stat sbuf;
+#ifndef _MSC_VER
    uid_t userid = getuid();
+#endif
    time_t recent = 0;
    char *snptr;
    int pid;
@@ -252,16 +268,22 @@ void findcrashfiles()
 	       pid = -1;
 	    *dotptr = '.';
          }
-         if ((!stat(_STR, &sbuf)) && (sbuf.st_uid == userid)) {
+         if ((!stat(_STR, &sbuf))
+#ifndef _MSC_VER
+	     && (sbuf.st_uid == userid)
+#endif
+	     ) {
 	    if ((recent == 0) || (sbuf.st_ctime > recent)) {
 
 	       /* Check if the PID belongs to an active process	*/
 	       /* by sending a CONT signal and checking if 	*/
 	       /* there was no error result.			*/
 
+#ifndef _MSC_VER
 	       if (pid != -1)
 		  if (kill((pid_t)pid, SIGCONT) == 0)
 		     continue;
+#endif
 
 	       recent = sbuf.st_ctime;
 	       strcpy(_STR2, _STR);
@@ -298,6 +320,8 @@ void findcrashfiles()
 /* Match a filename extension against the file filter string.		*/
 /*----------------------------------------------------------------------*/
 
+#if !defined(XC_WIN32) || defined(TCL_WRAPPER)
+
 Boolean match_filter(char *fname, char *filter)
 {
    char *dotptr = strrchr(fname, '.');
@@ -316,7 +340,9 @@ Boolean match_filter(char *fname, char *filter)
 void listfiles(xcWidget w, popupstruct *okaystruct, caddr_t calldata)
 {
    XGCValues	values;
+#ifndef TCL_WRAPPER
    Arg wargs[2];
+#endif
    DIR *cwd;
    char *filter;
    Window lwin = xcWindow(w);
@@ -469,7 +495,7 @@ void newfilelist(xcWidget w, popupstruct *okaystruct)
 #ifdef TCL_WRAPPER
    int bval;
    int result;
-   char *cstr = (char *)Tcl_GetVar2(xcinterp, "XCOps", "filter", TCL_NAMESPACE_ONLY);
+   char *cstr = (char *)Tcl_GetVar2(xcinterp, "XCOps", "filter", 0);
    if (cstr == NULL) {
       Wprintf("Error: No variable $XCOps(filter) in Tcl!");
       return;
@@ -509,7 +535,9 @@ void newfilelist(xcWidget w, popupstruct *okaystruct)
 
 void fileselect(xcWidget w, popupstruct *okaystruct, XButtonEvent *event)
 {
+#ifndef TCL_WRAPPER
    Arg wargs[2];
+#endif
    Window lwin = xcWindow(w);
    Dimension textwidth, textheight;
    short filenum, n = 0;
@@ -631,7 +659,9 @@ void fileselect(xcWidget w, popupstruct *okaystruct, XButtonEvent *event)
 
 void showlscroll(xcWidget w, caddr_t clientdata, caddr_t calldata)
 {
+#ifndef TCL_WRAPPER
    Arg wargs[2];
+#endif
    Window swin = xcWindow(w);
    Dimension swidth, sheight;
    int pstart, pheight, finscr;
@@ -668,7 +698,9 @@ void showlscroll(xcWidget w, caddr_t clientdata, caddr_t calldata)
 
 void draglscroll(xcWidget w, popupstruct *okaystruct, XButtonEvent *event)
 {
+#ifndef TCL_WRAPPER
    Arg wargs[1];
+#endif
    Dimension sheight;
    int phheight, finscr, flsave = flstart;
    short n = 0;
@@ -812,6 +844,8 @@ void genfilelist(xcWidget parent, popupstruct *okaystruct, Dimension width)
 
 #endif 	/* TCL_WRAPPER */
 
+#endif
+
 /*-------------------------------------------------------------------------*/
 /* Look for a directory name in a string and update cwdname accordingly	   */
 /*-------------------------------------------------------------------------*/
@@ -819,11 +853,13 @@ void genfilelist(xcWidget parent, popupstruct *okaystruct, Dimension width)
 int lookdirectory(char *lstring, int nchars)
 {
    int slen;
+   DIR *cwd = NULL;
 
    xc_tilde_expand(lstring, nchars);
    slen = strlen(lstring);
 
-   if (lstring[slen - 1] == '/' || (opendir(lstring) != NULL)) {
+   if (lstring[slen - 1] == '/' || ((cwd=opendir(lstring)) != NULL)) {
+      if (cwd) closedir(cwd);
       if (lstring[slen - 1] != '/') strcat(lstring, "/");
       cwdname = (char *)realloc(cwdname, (slen + 2) * sizeof(char));
       strcpy(cwdname, lstring);
