@@ -913,7 +913,7 @@ void labelbbox(labelptr labox, XPoint *npoints, objinstptr callinst)
    TextExtents tmpext;
    short j;
 
-   tmpext = ULength(labox->string, callinst, 0.0, 0, NULL);
+   tmpext = ULength(labox, callinst, 0.0, 0, NULL);
    points[0].x = points[1].x = (labox->justify & NOTLEFT ? 
 	       (labox->justify & RIGHT ? -tmpext.width :
 		-tmpext.width / 2) : 0);
@@ -1623,10 +1623,10 @@ void UDrawTextLine(labelptr curlabel, short tpos)
    SetFunction(dpy, areawin->gc, GXxor);
    SetForeground(dpy, areawin->gc, AUXCOLOR ^ BACKGROUND);
 
-   tmpext = ULength(curlabel->string, areawin->topinstance, 0.0, tpos, NULL);
+   tmpext = ULength(curlabel, areawin->topinstance, 0.0, tpos, NULL);
    xdist = tmpext.width;
    xbase = tmpext.base;
-   tmpext = ULength(curlabel->string, areawin->topinstance, 0.0, 0, NULL);
+   tmpext = ULength(curlabel, areawin->topinstance, 0.0, 0, NULL);
 
    points[0].x = (tmpjust & NOTLEFT ?
         (tmpjust & RIGHT ? -tmpext.width : -tmpext.width >> 1) : 0)
