@@ -694,11 +694,13 @@ void default_keybindings()
    add_binding(ALL_WINDOWS, XK_L, XCF_Library_Directory);
    add_binding(ALL_WINDOWS, XK_c, XCF_Library_Copy);
    add_binding(ALL_WINDOWS, XK_E, XCF_Library_Edit);
+   add_binding(ALL_WINDOWS, XK_e, XCF_Library_Edit);
    add_binding(ALL_WINDOWS, XK_D, XCF_Library_Delete);
    add_binding(ALL_WINDOWS, XK_C, XCF_Library_Duplicate);
    add_binding(ALL_WINDOWS, XK_H, XCF_Library_Hide);
    add_binding(ALL_WINDOWS, XK_V, XCF_Library_Virtual);
    add_binding(ALL_WINDOWS, XK_M, XCF_Library_Move);
+   add_binding(ALL_WINDOWS, XK_m, XCF_Library_Move);
    add_binding(ALL_WINDOWS, XK_P, XCF_Page_Directory);
    add_binding(ALL_WINDOWS, XK_less, XCF_Library_Pop);
    add_binding(ALL_WINDOWS, HOLD | BUTTON1, XCF_Library_Pop);
