@@ -2,9 +2,11 @@
 # EDIF file parser for XCircuit
 #------------------------------------------------------------------------
 # Written by Tim Edwards, MultiGiG, Inc., Scotts Valley, CA
-# July 18, 2006
 #------------------------------------------------------------------------
 # Revision history:
+#   Revision 0:  July 18, 2006 by Tim Edwards
+#   Revision 1:  July 24, 2006 by Jan Sundermeyer  
+#   Revision 2:  July 30, 2006 by Jan Sundermeyer
 #------------------------------------------------------------------------
 
 # "Standard" scaling:  converts a typical factors-of-10 coordinate system
@@ -13,6 +15,9 @@
 set Opts(scalen) 8
 set Opts(scaled) 5
 
+set symbolview {symbol symbolr spectre hspice spectreS}
+set subst_list {}
+
 #------------------------------------------------------------------------
 # EDIF rotations are the reverse of xcircuit rotations.
 #------------------------------------------------------------------------
@@ -193,24 +198,28 @@ proc parse_geometry {elemtype elemdata} {
       }
       name -
       stringDisplay {
-	 set dparams [lrange [lindex $elemdata 1] 1 end]
-
          # Parse various kinds of strings used by Cadence
 
 	 set dstring [lindex $elemdata 0]
+	 if {[lindex $dstring 0]== "array"} {
+	    set dstring [subst_name [lindex $dstring 1]]
+	 } else {
+	    set dstring [subst_name $dstring]
+	 }
 
 	 # Do EDIF-format ASCII escape sequence substitution
 	 while {[regexp -- {%([0-9]+)%} $dstring temp code] > 0} {
 	    set oval [dec_to_oct $code]
 	    regsub -- {%[0-9]+%} $dstring [subst "$oval"] dstring
 	 }
-
+	 
+	 set handle {}
          if {[string first "cds" $dstring] == 0} {
 	    switch -glob $dstring {
 	       cdsName* {set handle [label make normal [object name] {0 0}]}
 	       cdsParam* {set handle {}}
 	       cdsTerm* {
-		  if {[regexp {"(.+)"} $dstring temp pinname] > 0} {
+	   if {[regexp {"(.+)"} $dstring temp pinname] > 0} {
 		     set handle [label make pin $pinname {0 0}]
 		  } else {
 		     set handle [label make pin $dstring {0 0}]
@@ -218,10 +227,15 @@ proc parse_geometry {elemtype elemdata} {
 	       }
 	       default {set handle [label make normal $dstring {0 0}]}
 	    }
+	    set cds 1
 	 } else {
-	    set handle [label make normal $dstring {0 0}]
+	 	set cds 0
+	 }
+         foreach dparams [lrange $elemdata 1 end] {
+ 	 if {$cds == 0} { 
+		quiet_deselect
+	 	set handle [label make normal $dstring {0 0}]
 	 }
-
 	 if {$handle != {}} {
 	    foreach dtext $dparams {
 	       set dtk [lindex $dtext 0]
@@ -279,6 +293,7 @@ proc parse_geometry {elemtype elemdata} {
 	       }
 	    }
 	 }
+	 }
       }
       default {
 	 puts "Unsupported geometry block keyword $elemtype"
@@ -288,6 +303,31 @@ proc parse_geometry {elemtype elemdata} {
    return $handle
 }
 
+#------------------------------------------------------------------------
+# execute substitution of net names
+#------------------------------------------------------------------------
+
+proc subst_name {net} {
+
+   global subst_list
+
+   if {[llength $net] > 1} {
+      if {[lindex $net 0] == "rename"} {
+	 lappend subst_list [lrange $net 1 2]
+	 return [lindex $net 2]		
+      } else {
+      	 return $net
+      }
+   } else {
+      set pos [lsearch $subst_list "$net *"]
+      if {$pos > -1} {
+	 return [lindex [lindex $subst_list $pos] 1]
+      } else {
+ 	 return $net
+      }
+   }
+}
+
 #------------------------------------------------------------------------
 # Parse a "net" statement in the EDIF data.
 #------------------------------------------------------------------------
@@ -299,6 +339,10 @@ proc parse_net {netdata} {
    if {[llength $netString] > 1} {
       if {[lindex $netString 0] == "name"} {
 	 parse_geometry [lindex $netString 0] [lrange $netString 1 end]
+      } elseif {[lindex $netString 0] == "rename"} {
+      	 parse_geometry [lindex $netString 0] [lrange $netString 1 end]      
+      } elseif {[lindex $netString 0] == "array"} {
+	 parse_geometry [lindex $netString 0] [lrange $netString 1 end]      
       } else {
 	 puts "Unknown net name $netString"
 	 return
@@ -329,6 +373,11 @@ proc parse_net {netdata} {
 proc parse_instance {instName instdata} {
    quiet_deselect
    set handle {}
+   if {[lindex $instName 0] == "array"} {
+   	set instName [subst_name [lindex $instName 1]]
+   } else {
+   	set instName [subst_name $instName]
+   }
    foreach phrase $instdata {
       set keyword [lindex $phrase 0]
       switch $keyword {
@@ -417,17 +466,18 @@ proc parse_instance {instName instdata} {
 proc parse_port {labellist portdata} {
 
    set portString [lindex $portdata 0]
+   set plabel {}
 
    if {[llength $portString] > 1} {
       if {[lindex $portString 0] == "name"} {
 	 set plabel [parse_geometry [lindex $portString 0] [lrange $portString 1 end]]
-	 set portName [lindex $portString 1]
+	 set portName [subst_name [lindex $portString 1]]
       } else {
 	 puts "Unknown portImplementation pin $portString"
 	 return
       }
    } else {
-      set portName $portString
+      set portName [subst_name $portString]
    }
 
    if {$labellist != {}} {
@@ -536,6 +586,9 @@ proc parse_page {cellname portlist pagedata} {
 #------------------------------------------------------------------------
 
 proc parse_contents {celltype cellname portlist contentdata} {
+
+   global symbolview
+
    set labellist {}
    foreach phrase $contentdata {
       set keyword [lindex $phrase 0]
@@ -570,7 +623,10 @@ proc parse_contents {celltype cellname portlist contentdata} {
       }
    }
 
-   if {"$celltype" == "symbol"} {
+   # search for all symbol views
+   # following list contains these viewnames
+
+   if {[lsearch $symbolview $celltype] > -1} {
       # Create standard parameters
       parameter make substring class "X"
       parameter make substring idx "?"
@@ -597,6 +653,7 @@ proc parse_contents {celltype cellname portlist contentdata} {
          label make info "$itext" "$x $y"
       }
    }
+
 }
 
 #------------------------------------------------------------------------
@@ -655,7 +712,14 @@ proc parse_interface {cellname ifacedata} {
       #    to parameter "class".
 
       switch $keyword {
-	 port {lappend portlist [lindex $phrase 1]}
+	 port {
+	    if {[lindex [lindex $phrase 1] 0] == "array"} {
+	       set zw [subst_name [lindex [lindex $phrase 1] 1]]
+	    } else {
+	       set zw [subst_name [lindex $phrase 1]]
+	    }
+	    lappend portlist $zw
+	 }
 	 symbol {parse_contents symbol $cellname $portlist [lrange $phrase 1 end]}
 	 default {puts "Unsupported interface block keyword $keyword"}
       }
@@ -741,6 +805,9 @@ proc parse_symbol {libname cellname viewdata} {
 #------------------------------------------------------------------------
 
 proc parse_cell {libname cellname celldata} {
+
+   global symbolview
+
    foreach phrase $celldata {
       set keyword [lindex $phrase 0]
       # Possible other keywords to handle:
@@ -748,11 +815,13 @@ proc parse_cell {libname cellname celldata} {
       switch $keyword {
 	 view {
 	    set viewType [lindex $phrase 1]
-	    switch $viewType {
-	       symbolr -
-	       symbol {parse_symbol $libname $cellname [lrange $phrase 2 end]}
-	       schematic {parse_schematic $cellname [lrange $phrase 2 end]}
-	       default {puts "Unsupported view type $viewType"}
+	    if {[lsearch $symbolview $viewType] > -1} {
+	    	parse_symbol $libname $cellname [lrange $phrase 2 end]
+	    } else {
+	       switch $viewType {
+	          schematic {parse_schematic $cellname [lrange $phrase 2 end]}
+	          default {puts "Unsupported view type $viewType"}
+	       }
 	    }
 	 }
 	 default {puts "Unsupported cell block keyword $keyword"}
