@@ -34,11 +34,11 @@ proc xcircuit::writeall {} {
 	 if {$XCOps(cbox${i}) > 0} {
 	    set pagelist [pack slaves .writeall.list.pframe${i}]
 	    set firstpage [lindex $pagelist 0]
-	    set pageno [${pagelist} cget -text]
+	    set pageno [${firstpage} cget -text]
 	    if {$pageno == "-" || $pageno == "X"} {
 	       library [.writeall.list.f${i} cget -text] save
 	    } else {
-	       page ${pageno} saveonly
+	       page ${pageno} save
 	    }
 	 }
 	 unset XCOps(cbox${i})
@@ -69,20 +69,19 @@ proc xcircuit::promptwriteall {} {
    }
    set filelist [lsort -unique -dictionary $filelist]
 
-   set libraries [library "User Library"]
-   set liblist {}
-   set badlibslist {}
-   for {set i 1} {$i < $libraries} {incr i} {
-      if {[library $i changed] > 0} {
-	 if {[library $i writable] > 0} {
-	    lappend liblist [library $i]
+   set techlist {}
+   set badtechslist {}
+   foreach tech [technology list] {
+      if {[technology changed $tech] > 0} {
+	 if {[technology writable $tech] > 0} {
+	    lappend techlist $tech
 	 } else {
-	    lappend badlibslist [library $i]
+	    lappend badtechslist $tech
 	 }
       }
    }
 
-   set filestowrite [expr [llength $filelist] + [llength $liblist]]
+   set filestowrite [expr [llength $filelist] + [llength $techlist]]
 
    # Set up the "writeall" window
 
@@ -97,11 +96,12 @@ proc xcircuit::promptwriteall {} {
    pack .writeall.bbar -side top -padx 5 -pady 5 -fill x
 
    if {$filestowrite == 0} {
-      label .writeall.tbar.title -text "(No modified pages or libraries to write)" -bg \
+      label .writeall.tbar.title -text \
+		"(No modified pages or technologies to write)" -bg \
 		beige -fg gray40
       pack .writeall.tbar.title -side left
    } else {
-      label .writeall.tbar.title -text "Write All Modified Pages and Libraries:" \
+      label .writeall.tbar.title -text "Write All Modified Pages and Technologies:" \
 		-bg beige -fg blue
       pack .writeall.tbar.title -side left
 
@@ -139,23 +139,22 @@ proc xcircuit::promptwriteall {} {
       grid .writeall.list.cbox${k} -row $k -column 2 -sticky news
    }
 
-   foreach j $liblist {
+   foreach j $techlist {
       incr k
       label .writeall.list.f${k} -text "$j" -anchor w -bg beige
       frame .writeall.list.pframe${k} -bg beige
       set XCOps(cbox${k}) 1
       checkbutton .writeall.list.cbox${k} -bg beige -variable XCOps(cbox${k})
 
-      button .writeall.list.pframe${k}.b1 -text "-" -bg \
-			white -command "library goto $j ; \
-			promptsavelib"
+      button .writeall.list.pframe${k}.b1 -text "-" -bg white \
+			-command "xcircuit::promptsavetech $j"
       pack .writeall.list.pframe${k}.b1 -side left -padx 5
       grid .writeall.list.f${k} -row $k -column 0 -sticky news
       grid .writeall.list.pframe${k} -row $k -column 1 -sticky news
       grid .writeall.list.cbox${k} -row $k -column 2 -sticky news
    }
 
-   foreach j $badlibslist {
+   foreach j $badtechslist {
       incr k
       label .writeall.list.f${k} -text "$j" -anchor w -bg beige -fg gray60
       frame .writeall.list.pframe${k} -bg beige
@@ -163,7 +162,7 @@ proc xcircuit::promptwriteall {} {
       checkbutton .writeall.list.cbox${k} -bg beige -variable XCOps(cbox${k})
 
       button .writeall.list.pframe${k}.b1 -text "X" -bg white -fg gray60 \
-			-command "library goto $j"
+			-command "xcircuit::promptsavetech $j"
       pack .writeall.list.pframe${k}.b1 -side left -padx 5
       grid .writeall.list.f${k} -row $k -column 0 -sticky news
       grid .writeall.list.pframe${k} -row $k -column 1 -sticky news
@@ -173,14 +172,17 @@ proc xcircuit::promptwriteall {} {
    if {$filestowrite > 0} {
       button .writeall.bbar.okay -text Write -bg beige -command \
 		{xcircuit::writeall}
-   } else {
-      button .writeall.bbar.okay -text Force -bg beige -command \
-		{xcircuit::forcewriteall}
+      pack .writeall.bbar.okay -side left -ipadx 10 -padx 5
    }
+
+   if {$filestowrite < $pages} {
+      button .writeall.bbar.force -text Force -bg beige -command \
+	{xcircuit::forcewriteall}
+      pack .writeall.bbar.force -side left -ipadx 10 -padx 5
+   }
+
    button .writeall.bbar.cancel -text Cancel -bg beige -command \
 	{destroy .writeall}
-
-   pack .writeall.bbar.okay -side left -ipadx 10 -padx 5
    pack .writeall.bbar.cancel -side right -ipadx 10 -padx 5
 }
 
