@@ -107,11 +107,7 @@ proc xcircuit::makesymbol {{filename ""} {orderedpins ""}} {
    if {$noschem == 1} {
       select $sbox
       set handle [object make $symbolname $XCOps(library)]
-      if {$handle == ""} {
-	 push [object parts]
-      } else {
-         push $handle
-      }
+      push $handle
    }
 
    # Ordered right->left->bottom->top, on logical grounds.
