@@ -297,30 +297,18 @@ int is_library(objectptr thisobj)
    return -1;
 }
 
-/*------------------------------------------------------*/
-/* Check if a library (given by name) exists.  If it	*/
-/* does, return the library number.  If not, return -1	*/
-/*------------------------------------------------------*/
-
-int check_library(char *libname)
-{
-   int i;
-   
-   for (i = 0; i < xobjs.numlibs; i++)
-      if (!strcmp(xobjs.libtop[i + LIBRARY]->thisobject->name, libname))
-	 return i;
-
-   return -1;
-}
-
 /*------------------------------------------------------*/
 /* Check for library name (string).  Because XCircuit   */
 /* generates the text "Library: <filename>" for		*/
 /* library names, we also check against <filename>	*/
-/* only in these names.					*/
+/* only in these names (this library name syntax is	*/
+/* deprecated, but the check is retained for backwards	*/
+/* compatibility).					*/
+/*							*/
+/* If no library matches the given name, return -1.	*/
 /*------------------------------------------------------*/
 
-int name_to_library(char *libname)
+int NameToLibrary(char *libname)
 {
    char *slib;
    int i;
@@ -891,6 +879,7 @@ void composelib(short mode)
 
       if (fval < fontcount) {
 	 stringpart *strptr;
+	 char *locobjname;
 
 	 NEW_LABEL(drawname, libpage);
          libpage->parts++;
@@ -901,6 +890,7 @@ void composelib(short mode)
 	 (*drawname)->string->data.font = fval;
 	 strptr = makesegment(&((*drawname)->string), NULL);
 	 strptr->type = TEXT_STRING;
+
          strptr->data.string = strdup(libobj->name);
          (*drawname)->justify = TOP | NOTBOTTOM | NOTLEFT;
 
@@ -995,11 +985,11 @@ void catvirtualcopy()
       libobj = SELTOOBJINST(newselect);
       libinst = addtoinstlist(i, libobj->thisobject, TRUE);
       instcopy(libinst, libobj);
+      tech_mark_changed(GetObjectTechnology(libobj->thisobject));
    }
 
    clearselects();
    composelib(LIBRARY + i);
-   lib_mark_changed(i);
    drawarea(NULL, NULL, NULL);
 }
 
@@ -1125,6 +1115,7 @@ void catdelete()
 	 }
 
 	 /* Finally, delete the object (permanent---no undoing this!) */
+         tech_mark_changed(GetObjectTechnology(libobj->thisobject));
 	 reset(libobj->thisobject, DESTROY);
       }
    }
@@ -1133,7 +1124,6 @@ void catdelete()
 
    if ((i = is_library(topobject)) >= 0) {
       composelib(LIBRARY + i);
-      lib_mark_changed(i);
    }
 
    drawarea(NULL, NULL, NULL);
@@ -1217,32 +1207,37 @@ void linkedlistinsertafter(liblistptr *spec, int o1, int o2)
 /*------------------------------------------------------*/
 /* Set the "changed" flag in a library if any object	*/
 /* in that library has changed.				*/
+/*							*/
+/* If "technology" is NULL, check all objects,		*/
+/* otherwise only check objects with a matching		*/
+/* technology.						*/
 /*------------------------------------------------------*/
 
-void lib_set_changes(int libnum)
+void tech_set_changes(TechPtr refns)
 {
-   int j;
+   TechPtr ns;
+   int i, j;
    objectptr thisobj;
 
-   if ((xobjs.userlibs[libnum].flags & LIBRARY_CHANGED) != 0)
-      return;
-
-   for (j = 0; j < xobjs.userlibs[libnum].number; j++) {
-      thisobj = *(xobjs.userlibs[libnum].library + j);
-      if (getchanges(thisobj) > 0) {
-	 xobjs.userlibs[libnum].flags |= LIBRARY_CHANGED;
-	 break;
+   for (i = 0; i < xobjs.numlibs; i++) {
+      for (j = 0; j < xobjs.userlibs[i].number; j++) {
+         thisobj = *(xobjs.userlibs[i].library + j);
+         if (getchanges(thisobj) > 0) {
+            ns = GetObjectTechnology(thisobj);
+	    if ((refns == NULL) || (refns == ns)) 
+	       ns->flags |= LIBRARY_CHANGED;
+	 }
       }
    }
 }
 
 /*------------------------------------------------------*/
-/* Mark a library as having been modified.		*/
+/* Mark a technology as having been modified.		*/
 /*------------------------------------------------------*/
 
-void lib_mark_changed(int libnum)
+void tech_mark_changed(TechPtr ns)
 {
-   xobjs.userlibs[libnum].flags |= LIBRARY_CHANGED;
+   if (ns != NULL) ns->flags |= LIBRARY_CHANGED;
 }
 
 /*------------------------------------------------------*/
@@ -1340,11 +1335,9 @@ void catmove(int x, int y)
 
    unselect_all();
    composelib(LIBRARY + i);
-   lib_mark_changed(i);
    if (j != i) {
       composelib(LIBRARY + j);
       centerview(xobjs.libtop[LIBRARY + j]);
-      lib_mark_changed(j);
    }
 
    drawarea(NULL, NULL, NULL);
@@ -1523,7 +1516,6 @@ void copycat()
    addtoinstlist(USERLIB - LIBRARY, *newobj, FALSE);
 
    composelib(USERLIB);
-   lib_mark_changed(USERLIB - LIBRARY);
    unselect_all();
 
    if (areawin->topinstance == xobjs.libtop[USERLIB])
