@@ -772,8 +772,6 @@ int createlibrary(Boolean force)
    xobjs.userlibs[libnum - LIBRARY].library = (objectptr *) malloc(sizeof(objectptr));
    xobjs.userlibs[libnum - LIBRARY].number = 0;
    xobjs.userlibs[libnum - LIBRARY].instlist = NULL;
-   xobjs.userlibs[libnum - LIBRARY].filename = NULL;
-   xobjs.userlibs[libnum - LIBRARY].flags = (char)0;
 
    sprintf(_STR2, "xcircuit::newlibrarybutton \"%s\"", newlibobj->name);
    Tcl_Eval(xcinterp, _STR2);
