@@ -1215,14 +1215,16 @@ Boolean makeexprparam(objectptr refobject, char *key, char *value, int which)
    oparamptr newops;
    char *newkey;
 
-   /* Check against postscript reserved names */
+   /* Check against object names, which are reserved words */
 
-   newkey = checkpostscriptname(key, NULL, NULL);
+   newkey = checkvalidname(key, NULL);
+   if (newkey == NULL) newkey = key;
 
    /* Ensure that no two parameters have the same name! */
 
    if (check_param(refobject, newkey)) {
       Wprintf("There is already a parameter named %s!", newkey);
+      if (newkey != key) free(newkey);
       return FALSE;
    }
 
@@ -1233,7 +1235,7 @@ Boolean makeexprparam(objectptr refobject, char *key, char *value, int which)
    newops->which = which;
    newops->parameter.expr = strdup(value);
    incr_changes(refobject);
-   free(newkey);
+   if (newkey != key) free(newkey);
 
    return TRUE;
 }
@@ -1249,14 +1251,16 @@ Boolean makefloatparam(objectptr refobject, char *key, float value)
    oparamptr newops;
    char *newkey;
 
-   /* Check against postscript reserved names */
+   /* Check against object names, which are reserved words */
 
-   newkey = checkpostscriptname(key, NULL, NULL);
+   newkey = checkvalidname(key, NULL);
+   if (newkey == NULL) newkey = key;
 
    /* Ensure that no two parameters have the same name! */
 
    if (check_param(refobject, newkey)) {
       Wprintf("There is already a parameter named %s!", newkey);
+      if (newkey != key) free(newkey);
       return FALSE;
    }
 
@@ -1267,7 +1271,7 @@ Boolean makefloatparam(objectptr refobject, char *key, float value)
    newops->which = P_NUMERIC;
    newops->parameter.fvalue = value;
    incr_changes(refobject);
-   free(newkey);
+   if (newkey != key) free(newkey);
 
    return TRUE;
 }
@@ -1282,14 +1286,16 @@ Boolean makestringparam(objectptr refobject, char *key, stringpart *strptr)
    oparamptr newops;
    char *newkey;
 
-   /* Check against postscript reserved names */
+   /* Check against object names, which are reserved words */
 
-   newkey = checkpostscriptname(key, NULL, NULL);
+   newkey = checkvalidname(key, NULL);
+   if (newkey == NULL) newkey = key;
 
    /* Ensure that no two parameters have the same name! */
 
    if (check_param(refobject, newkey)) {
       Wprintf("There is already a parameter named %s!", newkey);
+      if (newkey != key) free(newkey);
       return FALSE;
    }
 
@@ -1300,7 +1306,7 @@ Boolean makestringparam(objectptr refobject, char *key, stringpart *strptr)
    newops->which = P_SUBSTRING;
    newops->parameter.string = strptr;
    incr_changes(refobject);
-   free(newkey);
+   if (newkey != key) free(newkey);
 
    return TRUE;
 }
@@ -1352,7 +1358,8 @@ void makenumericalp(genericptr *gelem, u_int mode, char *key)
    /* Ensure that no two parameters have the same name! */
 
    if (key) {
-      keyptr = checkpostscriptname(key, NULL, NULL);
+      keyptr = checkvalidname(key, NULL);
+      if (keyptr == NULL) keyptr = key;
    }
    else {
       strcpy(new_key, param_keys[mode]);
@@ -1538,7 +1545,7 @@ void makenumericalp(genericptr *gelem, u_int mode, char *key)
    }
 
 param_done:
-   if (keyptr != new_key) free(keyptr);
+   if ((keyptr != new_key) && (keyptr != key)) free(keyptr);
 }
 
 /*--------------------------------------------------------------*/
@@ -1547,7 +1554,7 @@ param_done:
 /* with a particular type, so we want to remove all of them.	*/
 /*--------------------------------------------------------------*/
 
-void unmakenumericalp(genericptr *gelem, u_int mode)
+void removenumericalp(genericptr *gelem, u_int mode)
 {
    genericptr *pgen;
    eparamptr epp;
@@ -1696,7 +1703,8 @@ void makeparam(labelptr thislabel, char *key)
 
    /* check parameter against reserved PostScript names */
 
-   newkey = checkpostscriptname(key, NULL, NULL);
+   newkey = checkvalidname(key, NULL);
+   if (newkey == NULL) newkey = key;
 
    /* First, place PARAM_START and PARAM_END structures at the	*/
    /* intended parameter boundaries				*/
@@ -1742,7 +1750,7 @@ void makeparam(labelptr thislabel, char *key)
 
    textend = 0;
    incr_changes(topobject);
-   free(newkey);
+   if (newkey != key) free(newkey);
 }
 
 /*--------------------------------------------------------------*/
@@ -1798,6 +1806,7 @@ void free_object_param(objectptr thisobj, oparamptr thisparam)
    int k, j, l = -1;
    liblistptr spec;
    oparamptr ops, lastops = NULL;
+   genericptr *pgen;
    char *key = thisparam->key;
 
    /* Find all instances of this object and remove any parameter */
@@ -1825,6 +1834,29 @@ void free_object_param(objectptr thisobj, oparamptr thisparam)
       for (spec = xobjs.userlibs[l].instlist; spec != NULL; spec = spec->next) 
          destroyinst(spec->thisinst, thisobj, key);
 
+   /* Remove the parameter from any labels that it might occur in */
+
+   for (pgen = thisobj->plist; pgen < thisobj->plist + thisobj->parts; pgen++) {
+      if (IS_LABEL(*pgen)) {
+	 Boolean pending = TRUE;
+	 stringpart *strptr;
+	 labelptr plab = TOLABEL(pgen);
+
+	 while (pending) {
+	    pending = FALSE;
+	    for (strptr = plab->string; strptr != NULL; strptr = strptr->nextpart) {
+	       if (strptr->type == PARAM_START) {
+	          if (!strcmp(strptr->data.string, key)) {
+		     unmakeparam(plab, strptr);
+		     pending = TRUE;
+		     break;
+	          }
+	       }
+	    }
+	 }
+      }
+   }
+
    /* Remove the parameter from the object itself, tidying up	*/
    /* the linked list after it.					*/
 
@@ -1863,12 +1895,9 @@ stringpart *searchparam(stringpart *tstr)
 
 void unmakeparam(labelptr thislabel, stringpart *thispart)
 {
-   genericptr *pgen;
-   labelptr plab;
    oparamptr ops;
-   stringpart *strptr, *lastpart, *nextpart, *endpart, *newstr, *subs;
+   stringpart *strptr, *lastpart, *endpart, *newstr, *subs;
    char *key;
-   Boolean is_last = True;
    
    /* make sure there is a parameter here */
 
@@ -1881,26 +1910,9 @@ void unmakeparam(labelptr thislabel, stringpart *thispart)
    /* Unparameterizing can cause a change in the string */
    undrawtext(thislabel);
 
-   /* Now we need to see if there are other places in the object where	*/
-   /* this parameter is used.  If so, we delete only this particular	*/
-   /* instance of the parameter.  Otherwise, we delete the parameter	*/
-   /* and also remove it from the parameters list.			*/
-
-   for (pgen = topobject->plist; pgen < topobject->plist + topobject->parts;
-		pgen++) {
-      if (IS_LABEL(*pgen)) {
-	 plab = TOLABEL(pgen);
-	 for (strptr = plab->string; strptr != NULL; strptr = strptr->nextpart) {
-	    if (strptr->type == PARAM_START) {
-	       if ((strptr != thispart) && (!strcmp(strptr->data.string, key))) {
-		  is_last = False;
-		  break;
-	       }
-	    }
-	 }
-	 if (!is_last) break;
-      }
-   }
+   /* Methodology change 7/20/06:  Remove only the instance of the	*/
+   /* parameter.  The parameter itself will be deleted by a different	*/
+   /* method, using free_object_param().				*/
 
    ops = match_param(topobject, key);
    subs = ops->parameter.string;
@@ -1936,15 +1948,16 @@ void unmakeparam(labelptr thislabel, stringpart *thispart)
    mergestring(lastpart);
 
    redrawtext(thislabel);
-   if (is_last) {
-      freelabel(subs);
-      free_object_param(topobject, ops);
-   }
 }
 
-/*------------------------------------------------------*/
-/* Wrapper for unmakeparam()				*/
-/*------------------------------------------------------*/
+/*----------------------------------------------------------------------*/
+/* Wrapper for unmakeparam().  Remove a parameterized substring from a	*/
+/* label, or remove a numeric parameter from an element.		*/
+/*									*/
+/* NOTE:  This routine should not combine the instance-only string	*/
+/* parameter removal and the numeric parameter deletion, which is	*/
+/* fundamentally different in nature.					*/
+/*----------------------------------------------------------------------*/
 
 void unparameterize(int mode)
 {
@@ -1994,11 +2007,11 @@ void unparameterize(int mode)
 	    if (strptr != NULL) unmakeparam(settext, strptr);
 	 }
 	 else if (mode == P_POSITION) {
-	    unmakenumericalp(topobject->plist + (*fselect), P_POSITION_X);
-	    unmakenumericalp(topobject->plist + (*fselect), P_POSITION_Y);
+	    removenumericalp(topobject->plist + (*fselect), P_POSITION_X);
+	    removenumericalp(topobject->plist + (*fselect), P_POSITION_Y);
 	 }
 	 else
-	    unmakenumericalp(topobject->plist + (*fselect), mode);
+	    removenumericalp(topobject->plist + (*fselect), mode);
       }
       setparammarks(NULL);
    }
