@@ -190,7 +190,7 @@ extern short *xc_undelete(objinstptr, objectptr, short, short *);
 extern objectptr delete_element(objinstptr, short *, int, short);
 extern void printname(objectptr);
 extern Boolean checkname(objectptr);
-extern char *checkpostscriptname(char *, int *, objectptr);
+extern char *checkvalidname(char *, objectptr);
 extern objectptr finddot(void);
 extern void movepoints(genericptr *, short, short);
 #ifndef TCL_WRAPPER
@@ -281,14 +281,21 @@ extern char *varpscan(objectptr, char *, short *, genericptr, int, int, u_char);
 extern char *varscan(objectptr, char *, short *, genericptr, u_char);
 extern char *varfscan(objectptr, char *, float *, genericptr, u_char);
 extern objinstptr addtoinstlist(int, objectptr, Boolean);
-extern Boolean objectread(FILE *, objectptr, short, short, short, char *, int);
+extern Boolean objectread(FILE *, objectptr, short, short, short, char *,
+		int, TechPtr);
 void importfromlibrary(short, char *, char *);
-objectptr *new_library_object(short, char *, objlistptr *);
+objectptr *new_library_object(short, char *, objlistptr *, TechPtr);
 Boolean library_object_unique(short, objectptr, objlistptr);
 void add_object_to_library(short, objectptr);
 u_char *find_delimiter(u_char *);
 char standard_delimiter_end(char);
 
+extern Boolean CompareTechnology(objectptr, char *);
+extern TechPtr LookupTechnology(char *);
+extern TechPtr GetObjectTechnology(objectptr);
+extern TechPtr AddNewTechnology(char *, char *);
+extern void AddObjectTechnology(objectptr);
+
 #ifdef TCL_WRAPPER
 extern void setfile(char *, int);
 extern void savetemp(ClientData);
@@ -297,8 +304,11 @@ extern void setfile(xcWidget, xcWidget, caddr_t);
 extern void savetemp(XtPointer, xcIntervalId *);
 #endif
 extern void incr_changes(objectptr);
-extern void savelibpopup(xcWidget, pointertype, caddr_t);
-extern void savelibrary(xcWidget, int);
+extern void savelibpopup(xcWidget, char *, caddr_t);
+#ifndef TCL_WRAPPER
+extern void savelibrary(xcWidget, char *);
+#endif
+extern void savetechnology(char *, char *);
 extern void findfonts(objectptr, short *);
 extern void savefile(short);
 extern int printRGBvalues(char *, int, const char *);
@@ -457,10 +467,9 @@ extern short *pagetotals(int, short);
 extern Boolean is_virtual(objinstptr);
 extern int is_page(objectptr);
 extern int is_library(objectptr);
-extern int check_library(char *);
-extern int name_to_library(char *);
-extern void lib_set_changes(int);
-extern void lib_mark_changed(int);
+extern int NameToLibrary(char *);
+extern void tech_set_changes(TechPtr);
+extern void tech_mark_changed(TechPtr);
 extern int libfindobject(objectptr, int *);
 extern int libmoveobject(objectptr, int);
 extern void pagecat_op(int, int, int);
@@ -719,7 +728,7 @@ extern void makeparam(labelptr, char *);
 extern void searchinst(objectptr, objectptr, char *);
 extern stringpart *searchparam(stringpart *);
 extern void unmakeparam(labelptr, stringpart *);
-extern void unmakenumericalp(genericptr *, u_int);         
+extern void removenumericalp(genericptr *, u_int);         
 extern void unparameterize(int);
 extern void parameterize(int, char *);
 extern genericptr findparam(objectptr, void *, u_char);
@@ -900,7 +909,7 @@ extern int find_ordinal(int, labelptr, objinstptr);
 
 extern short UDrawChar(u_char, short, short, int, int);
 extern void UDrawString(labelptr, int, objinstptr);
-extern TextExtents ULength(stringpart *, objinstptr, float, short, XPoint *);
+extern TextExtents ULength(labelptr, objinstptr, float, short, XPoint *);
 extern void undrawtext(labelptr);
 extern void redrawtext(labelptr);
 extern void composefontlib(short);
