@@ -105,16 +105,33 @@ objectptr NameToPageObject(char *objname, objinstptr *ret_inst, int *ret_page)
 
 /*----------------------------------------------------------------------*/
 /* Find the object with the indicated name.				*/
+/*									*/
+/* WARNING:  If no library technology is given, XCircuit will return	*/
+/* the first object with the name "objname".  If there are multiple	*/
+/* objects of the same name in different technologies, then the one	*/
+/* returned may not be the one expected!				*/
 /*----------------------------------------------------------------------*/
 
 objectptr NameToObject(char *objname, objinstptr *ret_inst, Boolean dopages)
 {
    int i;
    liblistptr spec;
+   Boolean notech = FALSE;
+   char *techptr;
+
+   if (strstr(objname, "::") == NULL) notech = TRUE;
 
    for (i = 0; i < xobjs.numlibs; i++) {
       for (spec = xobjs.userlibs[i].instlist; spec != NULL; spec = spec->next) {
-         if (!strcmp(objname, spec->thisinst->thisobject->name)) {
+	 techptr = spec->thisinst->thisobject->name;
+	 if (notech) {
+	    techptr = strstr(spec->thisinst->thisobject->name, "::");
+	    if (techptr == NULL)
+	       techptr = spec->thisinst->thisobject->name;
+ 	    else
+	       techptr += 2;
+	 }
+         if (!strcmp(objname, techptr)) {
 	    if (ret_inst) *ret_inst = spec->thisinst;
 	    return spec->thisinst->thisobject;
 	 }
