@@ -1395,7 +1395,7 @@ void UDrawString(labelptr drawlabel, int passcolor, objinstptr localinst)
    tmpjust = flipadjust(drawlabel->justify);
 
    /* "natural" (unscaled) length */
-   tmpext = ULength(drawlabel->string, localinst, 0.0, 0, NULL);
+   tmpext = ULength(drawlabel, localinst, 0.0, 0, NULL);
 
    newpoint.x = (tmpjust & NOTLEFT ?
        (tmpjust & RIGHT ? -tmpext.width : -tmpext.width >> 1) : 0);
@@ -1563,8 +1563,22 @@ void UDrawString(labelptr drawlabel, int passcolor, objinstptr localinst)
 		} break;
 
 	     case TEXT_STRING:
-		for (textptr = strptr->data.string; textptr && *textptr != '\0';
-			textptr++) {
+		textptr = strptr->data.string;
+
+		/* Don't write technology names in catalog mode if this	*/
+		/* option is enabled	(but *not* CATTEXT_MODE!)	*/
+
+		if (((eventmode == CATALOG_MODE) && !xobjs.showtech)
+			|| ((eventmode == CATTEXT_MODE)
+			&& (drawlabel != TOLABEL(EDITPART)))) {
+		   char *nsptr = strstr(textptr, "::");
+		   if (nsptr != NULL) {
+		      textptr = nsptr + 2;
+		      pos += (int)nsptr - (int)strptr->data.string + 2;
+		   }
+		}
+
+		for (; textptr && *textptr != '\0'; textptr++) {
 		   pos++;
 		   UPushCTM();
 		   UPreMultCTM(DCTM, newpoint, tmpscale, 0);
@@ -1613,8 +1627,8 @@ enddraw:
 /* Compute the actual length of a string or portion thereof.		*/
 /*----------------------------------------------------------------------*/
 
-TextExtents ULength(stringpart *string, objinstptr localinst, float newscale,
-	short dostop, XPoint *tbreak)
+TextExtents ULength(labelptr drawlabel, objinstptr localinst,
+	float newscale, short dostop, XPoint *tbreak)
 {
    float oldscale, strscale, natscale, locscale = 1.0, xtotal = 0.5;
    float lasttotal = xtotal;
@@ -1632,14 +1646,14 @@ TextExtents ULength(stringpart *string, objinstptr localinst, float newscale,
    if (fontcount == 0) return retext;
 
    /* Don't draw temporary labels from schematic capture system */
-   else if (string->type != FONT_NAME) return retext;
+   else if (drawlabel->string->type != FONT_NAME) return retext;
 
    if (newscale > 0.0) natscale = UTopScale() * newscale;
    else natscale = 1.0;
      
    oldscale = strscale = natscale;
 
-   for (strptr = string; strptr != NULL;
+   for (strptr = drawlabel->string; strptr != NULL;
 		strptr = nextstringpart(strptr, localinst)) {
       switch (strptr->type) {
 	 case SUPERSCRIPT:
@@ -1714,7 +1728,22 @@ TextExtents ULength(stringpart *string, objinstptr localinst, float newscale,
 	       natscale = locscale;
 	    break;
 	 case TEXT_STRING:
-	    for (textptr = strptr->data.string; textptr && *textptr != '\0'; textptr++) {
+	    textptr = strptr->data.string;
+
+	    /* Don't write technology names in catalog mode if	*/
+	    /* the option is enabled, so ignore when measuring	*/
+
+	    if (((eventmode == CATALOG_MODE) && !xobjs.showtech)
+			|| ((eventmode == CATTEXT_MODE)
+			&& (drawlabel != TOLABEL(EDITPART)))) {
+		char *nsptr = strstr(textptr, "::");
+		if (nsptr != NULL) {
+		   textptr = nsptr + 2;
+		   locpos += (int)nsptr - (int)strptr->data.string + 2;
+		}
+	    }
+
+	    for (; textptr && *textptr != '\0'; textptr++) {
                if (dostop && (locpos >= dostop)) break;
 	       locpos++;
 
@@ -1741,7 +1770,7 @@ TextExtents ULength(stringpart *string, objinstptr localinst, float newscale,
 
    /* special case: return character position in retext.width */
    if (tbreak != NULL) {
-      int slen = stringlength(string, True, localinst);
+      int slen = stringlength(drawlabel->string, True, localinst);
       if ((tbreak->x - lasttotal) < (xtotal - tbreak->x))
 	 locpos = lastpos + 1;
       if (locpos < 1) locpos = 1;
