@@ -12,6 +12,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include <tk.h>
 
@@ -54,6 +55,7 @@ typedef struct {
 				 * embedded (malloc'ed).  For non-embedded
 				 * windows this is NULL. */
     char *exitProc;		/* Callback procedure upon window deletion. */
+    char *commandProc;		/* Callback procedure for commands sent to the window */
     char *mydata;		/* This space for hire. */
     int flags;			/* Various flags;  see below for
 				 * definitions. */
@@ -80,6 +82,8 @@ static Tk_ConfigSpec configSpecs[] = {
 	"", Tk_Offset(Simple, useThis), TK_CONFIG_NULL_OK},
     {TK_CONFIG_STRING, "-exitproc", "exitproc", "ExitProc",
 	"", Tk_Offset(Simple, exitProc), TK_CONFIG_NULL_OK},
+    {TK_CONFIG_STRING, "-commandproc", "commandproc", "CommandProc",
+	"", Tk_Offset(Simple, commandProc), TK_CONFIG_NULL_OK},
     {TK_CONFIG_STRING, "-data", "data", "Data",
 	"", Tk_Offset(Simple, mydata), TK_CONFIG_NULL_OK},
     {TK_CONFIG_END, (char *) NULL, (char *) NULL, (char *) NULL,
@@ -200,6 +204,7 @@ Tk_SimpleObjCmd(clientData, interp, objc, objv)
     simplePtr->background = NULL;
     simplePtr->useThis = NULL;
     simplePtr->exitProc = NULL;
+    simplePtr->commandProc = NULL;
     simplePtr->flags = 0;
     simplePtr->mydata = NULL;
 
@@ -232,7 +237,12 @@ Tk_SimpleObjCmd(clientData, interp, objc, objv)
  *
  *	This procedure is invoked to process the Tcl command
  *	that corresponds to a simple widget.  See the user
- *	documentation for details on what it does.
+ *	documentation for details on what it does.  If the
+ *	"-commandProc" option has been set for the window,
+ *	then any unknown command (neither "cget" nor "configure")
+ *	will execute the command procedure first, then attempt
+ *	to execute the remainder of the command as an independent
+ *	Tcl command.
  *
  * Results:
  *	A standard Tcl result.
@@ -268,7 +278,16 @@ SimpleWidgetObjCmd(clientData, interp, objc, objv)
     if (Tcl_GetIndexFromObj(interp, objv[1],
 		(CONST84 char **)simpleOptions, "option", 0,
 		&index) != TCL_OK) {
-	return TCL_ERROR;
+	if (simplePtr->commandProc != NULL) {
+	   Tcl_ResetResult(simplePtr->interp);
+	   if (Tcl_EvalEx(simplePtr->interp, simplePtr->commandProc, -1, 0)
+			!= TCL_OK)
+	      return TCL_ERROR;
+	   else
+	      return Tcl_EvalObjv(simplePtr->interp, --objc, ++objv, TCL_EVAL_DIRECT);
+	}
+	else
+	   return TCL_ERROR;
     }
     Tcl_Preserve((ClientData) simplePtr);
     switch ((enum options) index) {
