@@ -574,6 +574,7 @@ short undo_one_action()
    short *slist;
    XPoint *delta, position;
    int i, snum, npage, opage;
+   int savemode;
    float fnum;
    genericptr egen;
    labelptr thislabel;
@@ -605,6 +606,7 @@ short undo_one_action()
    /* Setting eventmode to UNDO_MODE prevents register_for_undo() from 	*/
    /* being called again while executing the event.			*/
 
+   savemode = eventmode;
    eventmode = UNDO_MODE;
 
    /* type-dependent part */
@@ -640,7 +642,8 @@ short undo_one_action()
 	    break;
 	 }
 	 else {
-	    delete_one_element(thisrecord->thisinst, egen); /* XXX egen is uninitialized! */
+	    /* XXX egen is uninitialized! */
+	    delete_one_element(thisrecord->thisinst, egen);
 	 }
 
 	 /* Put back all the parts */
@@ -874,7 +877,16 @@ short undo_one_action()
 	 break;
    }
 
-   eventmode = NORMAL_MODE;	/* Set on a per-event-type basis? */
+   /* Does this need to be set on a per-event-type basis? */
+   switch (savemode) {
+      case CATALOG_MODE:
+      case CATTEXT_MODE:
+	 eventmode = CATALOG_MODE;
+	 break;
+      default:
+	 eventmode = NORMAL_MODE;
+	 break;
+   }
 
    /* Diagnostic, to check if all multiple-event undo series are resolved */
    if (thisrecord->idx < 0) {
@@ -913,6 +925,7 @@ short redo_one_action()
    editelement *erec;
    scaleinfo *escale;
    int i, tpage, snum;
+   int savemode;
    float fnum;
    labelptr thislabel;
    arcptr thisarc;
@@ -940,6 +953,7 @@ short redo_one_action()
       return 0;
    }
 
+   savemode = eventmode;
    eventmode = UNDO_MODE;
 
    /* type-dependent part */
@@ -1178,7 +1192,17 @@ short redo_one_action()
 	 break;
    }
 
-   eventmode = NORMAL_MODE;	/* Set on a per-event-type basis? */
+   /* Does this need to be set on a per-event-type basis? */
+   switch (savemode) {
+      case CATALOG_MODE:
+      case CATTEXT_MODE:
+	 eventmode = CATALOG_MODE;
+	 break;
+      default:
+	 eventmode = NORMAL_MODE;
+	 break;
+   }
+
    areawin = savewindow;
 
    return thisrecord->idx;
