@@ -304,6 +304,7 @@ u_short countchanges(char **promptstr)
    u_short locchanges, changes = 0, words = 1;
    objectptr thisobj;
    char *fname;
+   TechPtr ns;
 
    if (promptstr != NULL) slen += strlen(*promptstr);
 
@@ -327,16 +328,12 @@ u_short countchanges(char **promptstr)
 
    /* Check all library objects for unsaved changes */
 
-
-   for (i = 0; i < xobjs.numlibs; i++) {
-      lib_set_changes(i);
-      if ((xobjs.userlibs[i].flags & LIBRARY_CHANGED) != 0) {
+   for (ns = xobjs.technologies; ns != NULL; ns = ns->next) {
+      tech_set_changes(ns);
+      if ((ns->flags & LIBRARY_CHANGED) != 0) {
 	 changes++;
 	 if (promptstr != NULL) {
-	    if (xobjs.userlibs[i].filename != NULL)
-	          fname = xobjs.userlibs[i].filename;
-	    else
-	         fname = xobjs.libtop[i + LIBRARY]->thisobject->name;
+	    fname = ns->filename;
 	    slen += strlen(fname) + 2;
 	    *promptstr = (char *)realloc(*promptstr, slen);
 	    if ((words % 8) == 0) strcat(*promptstr, ",\n");
@@ -1131,7 +1128,8 @@ void pre_initialize()
    xobjs.pagelist[0]->pagesize.y = 792;
 
    xobjs.hold = TRUE;
-   xobjs.suspend = (char)-1;	/* Normal drawing mode (no graphics suspend) */ 
+   xobjs.showtech = FALSE;
+   xobjs.suspend = (char)0;	/* Suspend graphics until finished with startup */
    xobjs.new_changes = 0;
    xobjs.do_replace = -1;	/* default: replace NONE */
    xobjs.filefilter = TRUE;
@@ -1140,6 +1138,7 @@ void pre_initialize()
    signal(SIGINT, dointr);
    printtime_id = 0;
 
+   xobjs.technologies = NULL;
    xobjs.undostack = NULL;
    xobjs.redostack = NULL;
 
@@ -1156,11 +1155,9 @@ void pre_initialize()
    xobjs.fontlib.number = 0;
    xobjs.userlibs = (Library *) malloc(xobjs.numlibs * sizeof(Library));
    for (i = 0; i < xobjs.numlibs; i++) {
-      xobjs.userlibs[i].filename = NULL;
       xobjs.userlibs[i].library = (objectptr *) malloc(sizeof(objectptr));
       xobjs.userlibs[i].instlist = NULL;
       xobjs.userlibs[i].number = 0;
-      xobjs.userlibs[i].flags = (char)0;
    }
    xobjs.imagelist = NULL;
    xobjs.images = 0;
